package com.ruoyi.manage.service;

import com.ruoyi.manage.domain.WarnManage;

import java.util.List;

/**
 * 告警管理Service接口
 * 
 * @author boman
 * @date 2025-05-07
 */
public interface IWarnManageService 
{
    /**
     * 查询告警管理
     * 
     * @param warnId 告警管理主键
     * @return 告警管理
     */
    public WarnManage selectWarnManageByWarnId(Long warnId);

    /**
     * 查询告警管理列表
     * 
     * @param warnManage 告警管理
     * @return 告警管理集合
     */
    public List<WarnManage> selectWarnManageList(WarnManage warnManage);

    /**
     * 新增告警管理
     * 
     * @param warnManage 告警管理
     * @return 结果
     */
    public int insertWarnManage(WarnManage warnManage);

    /**
     * 修改告警管理
     * 
     * @param warnManage 告警管理
     * @return 结果
     */
    public int updateWarnManage(WarnManage warnManage);

    /**
     * 批量删除告警管理
     * 
     * @param warnIds 需要删除的告警管理主键集合
     * @return 结果
     */
    public int deleteWarnManageByWarnIds(Long[] warnIds);

    /**
     * 删除告警管理信息
     * 
     * @param warnId 告警管理主键
     * @return 结果
     */
    public int deleteWarnManageByWarnId(Long warnId);
}
